@@ -27,11 +27,11 @@ import (
 	"testing"
 	"time"
 
-	"github.com/container-orchestrated-devices/container-device-interface/pkg/cdi/validate"
-	cdi "github.com/container-orchestrated-devices/container-device-interface/specs-go"
 	oci "github.com/opencontainers/runtime-spec/specs-go"
 	"github.com/stretchr/testify/require"
 	"sigs.k8s.io/yaml"
+	"tags.cncf.io/container-device-interface/pkg/cdi/validate"
+	cdi "tags.cncf.io/container-device-interface/specs-go"
 )
 
 func TestNewCache(t *testing.T) {
@@ -1685,7 +1685,7 @@ devices:
 				"-0",
 			},
 			expected: [][]string{
-				[]string{
+				{
 					"vendor.com/device=dev1",
 				},
 				nil,
@@ -1746,25 +1746,25 @@ devices:
 				"-2",
 			},
 			expected: [][]string{
-				[]string{
+				{
 					"vendor.com/device=dev1",
 				},
-				[]string{
+				{
 					"vendor.com/device=dev1",
 					"vendor.com/device=dev2",
 				},
-				[]string{
+				{
 					"vendor.com/device=dev1",
 					"vendor.com/device=dev2",
 					"vendor.com/device=dev3",
 					"vendor.com/device=dev4",
 				},
-				[]string{
+				{
 					"vendor.com/device=dev2",
 					"vendor.com/device=dev3",
 					"vendor.com/device=dev4",
 				},
-				[]string{
+				{
 					"vendor.com/device=dev3",
 					"vendor.com/device=dev4",
 				},
